# Source of code
This folder has been adapted from the [private-pgm](https://github.com/ryan112358/private-pgm/blob/1da21c8b38149b05f1385b8e54116568b700b4fa) repository. Minor changes have been added to allow for the following features:

* Determinstic generation
* Conditional generation
* Sampling from OpenDP Gaussian rather than NumPy to avoid known floating-point precision vulnerabilities.
